@@ -10,7 +10,7 @@
 // power function, templated to use compile-time loop unrolling
 template<int P>
 inline double Pow(double x) {
-	return (Pow<P-1>(x) * x);
+  return (Pow<P-1>(x) * x);
 }
 
 template<>
@@ -20,7 +20,7 @@ inline double Pow<1>(double x) {
 
 template<>
 inline double Pow<0>(double x) {
-	return (1.0);
+  return (1.0);
 }
 
 // calculate euclidean distance
@@ -34,4 +34,10 @@ inline std::string num2str(T number, int precision=10) {
   return(ss.str());
 }
 
+void import_rij(Rcpp::List&, std::vector<arma::sp_mat>&);
+
+void import_connectivity_matrix_list(Rcpp::List&,
+                                     std::vector<std::vector<arma::sp_mat>>&,
+                                     bool);
+
 #endif
